@@ -26,11 +26,13 @@ def skip_without_credentials(func):
     rg = dask.config.get("cloudprovider.azure.azurevm.resource_group", None)
     vnet = dask.config.get("cloudprovider.azure.azurevm.vnet", None)
     security_group = dask.config.get("cloudprovider.azure.azurevm.security_group", None)
-    if rg is None or vnet is None or security_group is None:
+    location = dask.config.get("cloudprovider.azure.location", None)
+    if rg is None or vnet is None or security_group or location is None:
         return pytest.mark.skip(
             reason="""
         You must configure your Azure resource group and vnet to run this test.
 
+            $ export DASK_CLOUDPROVIDER__AZURE__LOCATION="<LOCATION>"
             $ export DASK_CLOUDPROVIDER__AZURE__AZUREVM__RESOURCE_GROUP="<RESOURCE GROUP>"
             $ export DASK_CLOUDPROVIDER__AZURE__AZUREVM__VNET="<VNET>"
             $ export DASK_CLOUDPROVIDER__AZURE__AZUREVM__SECURITY_GROUP="<SECUROTY GROUP>"
